@@ -6,10 +6,10 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#include "../effectloader.h"
-#include "../effects/effect_builtins.h"
+#include "effectloader.h"
+#include "effects/effect_builtins.h"
 #include "mock_effectshandler.h"
-#include "../scripting/scriptedeffect.h" // for mocking ScriptedEffect::create
+#include "scripting/scriptedeffect.h" // for mocking ScriptedEffect::create
 #include "testutils.h"
 // KDE
 #include <KConfig>
