@@ -41,9 +41,7 @@ public:
     bool isEnabled() const {
         return m_enabled;
     }
-    bool isActive() const {
-        return m_active;
-    }
+    bool isActive() const;
     void setActive(bool active);
     void hide();
     void show();
@@ -82,6 +80,7 @@ private:
     void setTextDirection(uint32_t serial, Qt::LayoutDirection direction);
     void startInputMethod();
     void stopInputMethod();
+    void setTrackedClient(AbstractClient *trackedClient);
 
     struct {
         QString text = QString();
@@ -90,7 +89,7 @@ private:
     } preedit;
 
     bool m_enabled = false;
-    bool m_active = false;
+    quint32 m_serial = 0;
     KStatusNotifierItem *m_sni = nullptr;
     QPointer<AbstractClient> m_inputClient;
     QPointer<AbstractClient> m_trackedClient;
